// $Id: ex_vmutil_attr.e,v 1.2 2005/04/07 21:32:29 ddmello Exp $

<'
// Add an owner attribute 


// 1.Define a new attribute type that inherits from vm_user_attribute and
//   implement its interface:
struct ex_vmutil_owner_attribute like vm_user_attribute {
    get_default_value(element: vm_attribute_container): string is { 
        result = "anon";
    };
    resolve_ntf_value(prev: string, current: string): string is { 
        result = current;
    };
    
    get_valid_container_names(): list of string is { 
       return {VM_CTNR_TEST; VM_CTNR_TEST_GROUP;VM_CTNR_RUN};
 
    };
  
    // This is a temp-workaround until we can resolve treatment      
    // of attributes with default values that are copied to vsof
    // (currently nothing is put in the vsof if value not specified in
    // vsif)
    // In this case making it an env-var might be a good idea, it can be used
    // e.g. to send email on a run-failure...
    is_env_attribute() : bool is {
       return TRUE;
    }; // is_env_attribut...

 }; //

// 2.Add one or more instances of this attribute to vManager by extending 
//   vm_manager.setup() and using the vm_manager.register_attribute() method:
extend vm_manager { 

   setup() is also { 
      register_attribute("owner",                      // attribute name 
                         new ex_vmutil_owner_attribute // attribute type 
      );
   }; 

}; 
'>

   


<'
// Add a new "Incomplete" Attribute to show Incomplete Runs
// Incomplete runs are those which were specified in the vsif but are not
// represented in the vsof

struct ex_vmutil_incomplete_attribute like vm_user_attribute { 
  
    // This attribute only has meaning when runs are grouped by session, 
    // show N/A otherwise
    compute_single_value(element: vm_attribute_container, res: 
        vm_display_result) is { 
         res.set_show_value("N/A"); 
      }; //
    
    
    // Compute the # of incomplete runs in a session  
    compute_grouped_value(group: vm_group, res: vm_display_result) is { 
         
       // Grab all runs in a group
       var runs : list of vm_run = group.get_runs();
         
       // First get the list of vsofs from which the runs came
       var vsofs : list of vm_vsof;
       vsofs = runs.apply(it.get_vsof()).sort(it).unique(it);
       
       // Now find out if the runs are grouped by session
       var sessions_grouping : bool;
       var curr_grouping := group.get_context().get_grouping();
       if curr_grouping.size() == 1 and curr_grouping[0].get_name() == "session_id" then {
          sessions_grouping = TRUE;
       }; // if curr_groupin...
       
       
       if vsofs.size() == 1 and sessions_grouping {
          // If from the same vsof and grouped by session we can compute 
          // a meaningful value
          var vsof : vm_vsof = vsofs[0];
          
          // Determine expected # of runs, completed/incomplete runs
          var total_runs : uint = vsof.get_attribute_value(vm_manager.get_attribute_by_name("runs_in_session")).as_a(uint);
          var completed_runs : uint = runs.size();
          var incomplete_runs : int = (total_runs-completed_runs);
          
          // Display and allow-to-sort-by incomplete value 
          res.set_show_value(dec(incomplete_runs)); 
          res.set_sort_value(dec(incomplete_runs)); 
       
          // Highlight non-zero incompletes
          if incomplete_runs != 0 {
             res.set_color(RED); 
          }; // if incomplete_r...

        
       } else {
          
          // Show "N/A" in situations where incomplete does not have meaning
          res.set_show_value("N/A"); 
          res.set_sort_value("N/A"); 

       }; // ! if vsofs.size...

       
      }; // compute_grouped...
 }; //


extend vm_manager {
   
   // Register the attribute so it can be used
    setup() is also { 
      
      register_attribute("Incomplete",         // attribute name 
            new ex_vmutil_incomplete_attribute // attribute type 
      );


   }; // setup() is also...
  
}; // extend vm_manag...
'>

<'

// General struct for attributes to be scanned from the simulation log
// Register as many as needed with appropriate names below
// Then add appropriate filters to a filter file to scan them
struct ex_vmutil_scanned_attribute like vm_user_attribute {
    get_default_value(element: vm_attribute_container): string is { 
        result = "N/A";
    };
    resolve_ntf_value(prev: string, current: string): string is { 
        result = current;
    };
    
    get_valid_container_names(): list of string is { 
       result = {VM_CTNR_RUN};
    };
   
}; // struct ex_vmuti...




extend vm_manager { 

   setup() is also { 
     // Add a hostname-attribute to be scanned from the log
      register_attribute("hostname",                      // attribute name 
                         new ex_vmutil_scanned_attribute // attribute type 
      );
   }; 

}; 

'>

///////////////////////////////////////////////////////////////////////////////
$Log: ex_vmutil_attr.e,v $
Revision 1.2  2005/04/07 21:32:29  ddmello
- Added a general definition for a scannable attribute
- registered a hostname attribute based on it

Revision 1.1  2004/12/14 21:20:27  ddmello
Initial revision

