//$Id: ex_vmutil_clean_run_dir.e,v 1.2 2005/10/25 00:42:25 ddmello Exp $

File cleanup procedure to traverse run directories and call a script
to clean up session files.

A procedure is similar to a vManager file policy but is not
implemented as a policy since the usage of these procedures is
intended to be cumulative (and perhaps the predefined "compress" will
be applied after cleanup), and vmanager does not appear to support
application of multiple policies to a single session yet.

Two procedures will be made available (instantiated under sys):
clean_passed and clean_failed.  To activate them their apply_proc()
methods need to be called with the vsof passed in as a parameter.

Each will traverse the run-dirs of the runs (passed or failed as
appropriate in each case and call a script that is assumed identified
in the appropriate env-var EX_VMUTIL_CLEAN_PASSED or
EX_VM_UTIL_CLEAN_FAILED.  The absolute-path of the run-dir is passed
to the script as a parameter when the script is invoked

Use the wrapper script ex_vmutil/scripts/ex_vmutil_clean_session.ecom
to execute the procedures

There is error-checking to make sure the scripts exist and a
"calling-card" is left in the session-dir when the procedure is
applied (empty file clean_passed_applied or clean_failed_applied)

<'
struct ex_vmutil_clean_proc {
   
   // This method will say whether passed or failed runs
   // will be cleaned
   get_run_status () : string is undefined;

   // This will tell the policy the name of the script to execute in
   // each directory
   
   get_script_name () : string is empty;

   // Will return the name of the cleanup procedure
   get_name () : string is undefined;

   // Call this method to apply the cleanup procedure
   apply_proc(session: vm_vsof) is undefined;

}; // struct ex_vmuti...   

'>

<'
// Some code common to passed/failed policies
extend ex_vmutil_clean_proc {
   
   // Assume will be extended as "is first" to set result 
   get_script_name () : string is only {
      
      assert files.file_exists(result) else 
      error("Script file ", result, " to clean ", get_run_status(), " runs does not exist");
      
   }; // get_script_name...
   
   // Implementation of the policy
   apply_proc(session: vm_vsof) is only {
      
      var run_status : string;
      var script_name : string;
      var runs_skipped: bool;

      run_status = get_run_status();
      script_name = get_script_name();

      assert (run_status in {"passed"; "failed"}) else
        error ("Run status must be \"passed\" or \"failed\"");

      //print run_status, script_name;  // FOR DEBUG
     
      
      // Leave a calling-card in the session-dir to show policy was applied
      var session_dir : string = session.get_attribute_value(vm_manager.get_attribute_by_name("session_dir"));
      var calling_card : string = appendf("touch %s/%s_applied", session_dir, get_name());
      
      //print calling_card;  // FOR DEBUG
      
      // Execute the command
      compute(output_from_check(calling_card));

      
      // Get the list of runs that meet the criteria
      var runs : list of vm_run;

      if run_status == "passed" {
          runs = session.get_runs().all(.has_passed() == TRUE);
      } else {
         runs = session.get_runs().all(.has_passed() == FALSE);;
      }; // ! if run_status...

      if runs.size() > 0 {
         var run_dir : string;
         var command : string;
         
         runs_skipped = FALSE;

         for each (run) in runs {
            run_dir = run.get_attribute_value(vm_manager.get_attribute_by_name("run_dir"));
            command = appendf("%s %s", script_name, run_dir);
            //print command;  // FOR DEBUG
            
            if (files.file_is_dir(run_dir)) {
            // Execute the command
               out(output_from_check(command));  
            } else {
               runs_skipped = TRUE;
            }; // ! if (files.fil...

         }; // for each (run) ...
         
         if runs_skipped {
            warning("Some run-dirs do not exist for session-dir ", session_dir);
         }; // if runs_skipped...


      }; // if runs.size() ...
      
   }; // apply_proc(sess...

   
}; // extend ex_vmuti...
'>


Now customize the passed/failed policies
<'
struct ex_vmutil_clean_passed like ex_vmutil_clean_proc {
   get_run_status () : string is only {
      result = "passed";
   }; // get_run_status ...
   
   // The script is assumed to be in an env-var
   get_script_name() : string is first {
      result = get_symbol("EX_VMUTIL_CLEAN_PASSED");
   }; // get_script_name...

   get_name ( ): string is only {
      result = "clean_passed";
   }; // get_name ( ): s...

}; // struct ex_vmuti...

'>

<'
struct ex_vmutil_clean_failed like ex_vmutil_clean_proc {
   get_run_status () : string is only {
      result = "failed";
   }; // get_run_status ...
   
   // The script is assumed to be in an env-var   
   get_script_name() : string is first {
      result = get_symbol("EX_VMUTIL_CLEAN_FAILED");
   }; // get_script_name...
   
   get_name ( ): string is only {
      result = "clean_failed";
   }; // get_name ( ): s...

}; // struct ex_vmuti...

// Instantiate structs to handle the cleanup procedures
extend sys {
   
   !clean_failed : ex_vmutil_clean_failed;
   !clean_passed : ex_vmutil_clean_passed;

   init( )is also {
      
      clean_failed= new;
      clean_passed = new;
      
   }; // init( )is also

   
}; // extend sys

'>

//////////////////////////////////////////////////////////////////////////////
$Log: ex_vmutil_clean_run_dir.e,v $
Revision 1.2  2005/10/25 00:42:25  ddmello
Added code to prevent execution of cleanup scripts if the run-dir does not exist

Revision 1.1  2005/10/25 00:08:16  ddmello
Initial revision



