///////////////////////////////////////////////////////////////////////////////
// $Id: ex_vmutil_debug_rerun.e,v 1.2 2005/06/17 11:47:23 ddmello Exp $
//   
// Purpose: Create a debug-rerun scheme
///////////////////////////////////////////////////////////////////////////////
<'

struct ex_vmutil_debug_rerun_scheme like vm_basic_rerun_scheme { 
    
    // Give it a name
    get_name(): string is only { 
        return "EX_VMUTIL_DEBUG_RERUN"; 
    };
    

    finalize_session(session: vm_vsif, orig_session: vm_vsof) is only { 
       
       var attr : vm_attribute;
       
       // Clear out the post_session_script attribute so that chaining 
       // using post_session-script
       // terminates after the debug-rerun-chain
       attr = vm_manager.get_attribute_by_name("post_session_script");
       session.set_attribute_value(attr, ""); 
       
    }; // finalize_sessio...

    finalize_test(test: vm_test, orig_run: vm_run) is only {
       
       var attr : vm_attribute;
       
       // Set the run_mode to "batch_debug" so the run-scripts can 
       // detect this as env-var $VMGR_RUN_MODE and take appropriate action
       attr = vm_manager.get_attribute_by_name("run_mode");
       test.set_attribute_value(attr, "interactive_debug"); 
    
    }; 

 }; //

// Register the scheme so it can be used with vManager
extend vm_manager { 
   setup() is also { 
      register_rerun_scheme("EX_VMUTIL_DEBUG_RERUN",  
       new ex_vmutil_debug_rerun_scheme); 
   }; 

}; //
'>


<'
// An additional attribute to use for communicating the 
// Failure-time to the run-script for debug-rerun

struct ex_vmutil_rerun_fail_time_attribute like vm_user_attribute {
   
   // Want it exported as an env-var
   is_env_attribute() : bool is only {
      result = TRUE;
   }; // is_env_attribut...

   // It will be written to a test-container by the rerun-scheme
   // and copied to the vsof for debugging
   get_valid_container_names() : list of string is only {
      result = {VM_CTNR_TEST; VM_CTNR_RUN};
   }; // get_valid_conta...
   
   copy_to_vsof() : bool is only {
      result = TRUE;
   }; // copy_to_vsof() ...

   // Its default value is empty
   get_default_value(element : vm_attribute_container) : string is only {
      result = "";
   }; // get_default_val...
   

   
}; // struct ex_vmuti...

// register the new rerun-fail-time attribute
extend vm_manager {
   setup() is also {
      register_attribute("rerun_fail_time",                     // attribute name 
                         new ex_vmutil_rerun_fail_time_attribute // attribute type 
      );      
   }; // setup() is also...

}; // extend vm_manag...


// Now grab the value for the attribute from the original run and pass it to the rerun
extend ex_vmutil_debug_rerun_scheme {
   
   
    finalize_test(test: vm_test, orig_run: vm_run) is also {
       
       var failures : list of vm_failure;
       
       failures = orig_run.get_failures();

       if failures is not empty {
          
          // Identify the first failure that occurred at time>0
          var first_interesting_failure : vm_failure;
          var fails_in_sim : list of vm_failure;

          try {
             fails_in_sim = failures.all(it.get_value("time").as_a(int) > 0);
          } else {
             warning("ex_vmutil : debug-rerun encountered a run with empty/missing fail-time attribute in a failure container");
             print failures.apply(it.get_value("time"));   
             print failures.apply(it.get_value("description"));                
          }; // ! try

          if fails_in_sim is not empty {

             // find the first one
             first_interesting_failure = fails_in_sim.min(it.get_value("time").as_a(int));
             
             var attr : vm_attribute; 
             attr = vm_manager.get_attribute_by_name("rerun_fail_time");

             test.set_attribute_value(attr, first_interesting_failure.get_value("time"));

             
          }; // if fails_in_sim...
       }; // if failures is ...
    }; // finalize_test(t...
}; // extend ex_vmuti...




'>
///////////////////////////////////////////////////////////////////////////////
$Log: ex_vmutil_debug_rerun.e,v $
Revision 1.2  2005/06/17 11:47:23  ddmello
Added code to handle cases where failure containers do not include a fail-time

Revision 1.1  2005/01/12 17:32:16  ddmello
Initial revision

