$Id: ex_vmutil_email.e,v 1.3 2005/01/12 19:14:57 ddmello Exp $

Code for generating email reports from vManager
   
<'
import ex_vmutil_email_h;
'>

<'
// Implementation
extend ex_vmutil_email_s {
    
     create_email_command () : string is only {
      result = appendf("cat %s | mail -s \"%s\" %s", temp_filename, subject, distr); 
   }; // create_email_co...
  
    send_email() is only {
       
       // create temp-file
       files.write_string_list(temp_filename, body);
       
       var email_command : string = create_email_command();
       print email_command;

       var rc : int; 
       rc = system(email_command);

       assert rc == 0 else
         error("'", email_command, "' exited with return value ", rc);
       
    }; // send_email() is...

 }; //

extend ex_vmutil_email_util_s {

   // Convert time since the epoch to a human-readable string
   convert_unix_time_attr(unix_time_attr_name : string, container : vm_attribute_container) : string is {
      
      var unix_time_attr_type := vm_manager.get_attribute_by_name(unix_time_attr_name); //that's the type (singleton)
      
      var res := new vm_display_result;
      
      unix_time_attr_type.compute_single_value(container, res);
      
      result = res.show_value;
      
   }; // convert_unix_ti...

     
   // Create a summary email for a session
    create_summary_email (
     
      vsof_filename : string,  // Session Output Format file to load
      named_view : string,     // View for Runs Analysis
      test_summary_page : string,  // Web page for summary results
      email_distribution : string  // Who ot send the email to
    
    ) : ex_vmutil_email_s is only {
       
       // For debug
       print vsof_filename, named_view, test_summary_page, email_distribution;
       
       var vsof_to_analyze : vm_vsof;
       
       // Read in the session of interest
       vsof_to_analyze = vm_manager.read_session(vsof_filename);

       
       // Apply the named view to create a context
       var curr_context : vm_context; 
       try {
          curr_context = vm_manager.create_context({vsof_to_analyze}, named_view);
       } else {
          error(appendf("Cannot create context with named view : %s", named_view));
       }; // ! try

       
       // Compute some interesting info
       var report_time : string = date_time();

       var total_runs : uint = vsof_to_analyze.get_attribute_value(vm_manager.get_attribute_by_name("runs_in_session")).as_a(uint);
       var completed_runs : uint = curr_context.get_runs().size();
       var incomplete_runs : int = (total_runs-completed_runs);
       
       
       var passed_runs : uint = curr_context.get_runs().all(it.has_passed() == TRUE).size();
       var failed_runs : uint = curr_context.get_runs().all(it.has_passed() == FALSE).size();
       
       var start_time : string = convert_unix_time_attr("session_start_time", vsof_to_analyze);
       var end_time : string = convert_unix_time_attr("session_end_time", vsof_to_analyze);


       var email_subject : string = appendf("Results for Session started at: %s", start_time);
       
       // Format the email body
       var email_text_los : list of string = << #:

         
vManager Session Results generated <(report_time)>
         
  Session started at <(start_time)>
         
  Total Runs:      <(total_runs)>
  Completed Runs:  <(completed_runs)>
  Incomplete Runs: <(incomplete_runs)>

  Passed:          <(passed_runs)>
  Failed:          <(failed_runs)>
         end #;

       if (test_summary_page != "") { 
          email_text_los.add(appendf("\n\nRegression Results posted at :\nhttp://%s", test_summary_page));
       }; // if (test_summar...

       
       var fail_report_los : list of string;
       fail_report_los = get_all_fails(curr_context);

       if fail_report_los is not empty {
         email_text_los.add(appendf("\nComplete Failure Report:\n-----------------------"));
         email_text_los.add(appendf("\n%-10s%-50s%-10s\n%-10s%-50s%-10s", "Owner", "Test", "Seed", "-----", "----", "----"));
          email_text_los.add(fail_report_los);
        
       }; // if fail_report_...
       
       // Create the email object
       result = new ex_vmutil_email_s with {
          .distr = email_distribution;
          .subject = email_subject;
          .body = email_text_los;
       }; // result = new cs...

    }; //

}; //


'>

<'
extend ex_vmutil_email_util_s {

    // Create emails for each test owner to report failures
    create_owner_emails (
     
      vsof_filename : string,    // Session output format to load
      named_view : string,       // View for Runs Analysis
      test_status_page : string, // Web page for test status details
      temp_files_dir : string, // Dir to save email text files in
      default_owner : string   // Gets owner-less failure report
    ) : list of ex_vmutil_email_s is {
       
       // For debug
       print vsof_filename, named_view, test_status_page;
       
       var vsof_to_analyze : vm_vsof;

       // Read in the session of interest
       vsof_to_analyze = vm_manager.read_session(vsof_filename);

       // Apply the named view to create a context
       var curr_context : vm_context; 
       curr_context = vm_manager.create_context({vsof_to_analyze}, named_view);
       

       // Compute some interesting info
       var report_time : string = date_time();
       var total_runs : uint = curr_context.get_runs().size();
       var passed_runs : uint = curr_context.get_runs().all(it.has_passed() == TRUE).size();
       var failed_runs : uint = curr_context.get_runs().all(it.has_passed() == FALSE).size();
             
       var start_time : string = convert_unix_time_attr("session_start_time", vsof_to_analyze);
       var end_time : string = convert_unix_time_attr("session_end_time", vsof_to_analyze);


       // Keep only failed runs in the context
       print curr_context.get_runs().size();
       
       // Group Runs by owner
       curr_context.add_grouping(vm_manager.get_attribute_by_name("owner"));
       
       // Traverse through the groups
       var curr_groups: list of vm_group = curr_context.get_groups();
       
       var curr_body : list of string; // body of the email
       var curr_owner : string;
       var temp_email : ex_vmutil_email_s;

       for each (group) in curr_groups {
          
          curr_body = {}; // curr_body =
          curr_owner = group.get_runs()[0].get_attribute_value(vm_manager.get_attribute_by_name("owner"));
          
          if curr_owner == "" {
             curr_owner = default_owner;
          }; // if curr_owner =...


          curr_body.add(appendf("Failure Report for test owner %s generated on %s\n\n", curr_owner, report_time));
           
          curr_body.add(appendf("Session started at: %s", start_time));

          if group.get_runs().has(.has_passed()== FALSE) {
             
             curr_body.add(appendf("\n\n%-10s%-50s%-10s\n%-10s%-50s%-10s", "Owner", "Test", "Seed", "-----", "----", "----"));          
             for each (owners_run) in group.get_runs() {  
             
                if owners_run.has_passed() == FALSE {
                   curr_body.add(appendf("%-10s%-50s%-10s",
                    owners_run.get_attribute_value(vm_manager.get_attribute_by_name("owner")),
                    owners_run.get_attribute_value(vm_manager.get_attribute_by_name("top_files")),
                    owners_run.get_attribute_value(vm_manager.get_attribute_by_name("seed"))
                   ));
                   
                   
                }; // if owners_run.h...

             }; //
       
             if test_status_page != "" {
                curr_body.add(appendf("\n\nRun Details, log files available at :\nhttp://%s", test_status_page));
             }; // if test_status_...

             // out(curr_body); // for debug
             
             // Create the email
             temp_email = new ex_vmutil_email_s with {
                .distr = curr_owner;
                .subject = appendf("%s's Failure Report for session started at: %s ", curr_owner, start_time);
                .body = curr_body;
                .temp_filename = append(temp_files_dir, "/", curr_owner, ".txt");
             }; // temp_email = ne...

             // Add it to the result list of emails
             result.add(temp_email);

          }; // if group.get_ru...

       }; // for each (group...
    
    }; //


    // Create the failure-summary for the summary email
    get_all_fails(context : vm_context) : list of string is {
       
       if context.get_runs().has(.has_passed()== FALSE) {
          
          // Group Runs by owner
          // DRD: workaround because I couldn't get sort-by-owner to work
          context.add_grouping(vm_manager.get_attribute_by_name("owner"));
       
          // Traverse through the groups
          var curr_groups: list of vm_group = context.get_groups();
          
          for each (group) in curr_groups {
             for each (test_run) in group.get_runs() {
                if test_run.has_passed() == FALSE {
                   result.add(appendf("%-10s%-50s%-10s",
                    test_run.get_attribute_value(vm_manager.get_attribute_by_name("owner")),
                    test_run.get_attribute_value(vm_manager.get_attribute_by_name("top_files")),
                    test_run.get_attribute_value(vm_manager.get_attribute_by_name("seed"))
                   ));
                }; // if test_run.has...
             }; // for each (test_...
          }; // for each (group...
       }; // if my_context.g...
    }; // get_all_fails(c...

 }; //


'>

///////////////////////////////////////////////////////////////////////////////

$Log: ex_vmutil_email.e,v $
Revision 1.3  2005/01/12 19:14:57  ddmello
Removed some incomplete code from last edit

Revision 1.2  2005/01/12 19:12:59  ddmello
Removed session-end-time from the email reports since this is empty if
queried in post_session_script

Revision 1.1  2004/12/15 00:59:12  ddmello
Initial revision

