#! /bin/sh -f

##############################################################################
# $Id: ex_vmutil_reports_post_session.sh,v 1.4 2006/04/12 17:26:23 ddmello Exp $
#
# Purpose: Example shell script for creating post-session reports
# 
# Usage:   Call this script using the post-session hook in the vsif
#
#          Ensure that you have set the following env-vars before 
#          launching your session:
#
#          EX_VMUTIL_VPLAN_FILE : package-relative or absolute path to 
#                                 verification plan file (.xml/.vplan)
#
#          EX_VMUTIL_VPLAN_PERSPECTIVE : Perspective of interest
#
#          Reports will be created in the 'html_reports' sub-dir of the
#          session directory
#
##############################################################################

# From : http://steve-parker.org/sh/exitcodes.shtml
check_errs()
{
  # Function. Parameter 1 is the return code
  # Para. 2 is text to display on failure.
  if [ "${1}" -ne "0" ]; then
    echo "ERROR # ${1} : ${2}"
    # as a bonus, make our script exit with the right error code.
    exit ${1}
  fi
}


# Since this script is called from the post-session hook, the 
# Reports can be placed in the session-dir under a new directory 'html_reports'
REPORTS_DIR=${BRUN_SESSION_DIR}/html_reports

###############



/bin/mkdir ${REPORTS_DIR}
check_errs $? "Error creating reports dir: $REPORTS_DIR"

# Runs reports

# Runs Report example
vmanager -batch -c "@ex_vmutil/scripts/ex_vmutil_runs_analysis;  @ex_vmutil/scripts/ex_vmutil_runs_summary \"${BRUN_SESSION_DIR}\" ${REPORTS_DIR} failure_report.html First_Failures FALSE"
check_errs $? "Error creating First_Failures report"


# Session Coverage report
vmanager -batch -c "@ex_vmutil/scripts/ex_vmutil_cov_analysis; @ex_vmutil/scripts/ex_vmutil_cov_summary \"${BRUN_SESSION_DIR}\" ${REPORTS_DIR} coverage_report.html Default ${EX_VMUTIL_VPLAN_FILE} \"${EX_VMUTIL_VPLAN_PERSPECTIVE}\" VPLAN_REPORT FALSE FALSE 10 FALSE"
check_errs $? "Error creating vPlan report"

# Regression report
vmanager -batch -c "@ex_vmutil/scripts/ex_vmutil_cov_analysis; @ex_vmutil/scripts/ex_vmutil_reg_summary \"${BRUN_SESSION_DIR}\" ${REPORTS_DIR} regression_report.html Sessions ${EX_VMUTIL_VPLAN_FILE} \"${EX_VMUTIL_VPLAN_PERSPECTIVE}\" ${EX_VMUTIL_FAILURE_VIEW} Sessions FALSE 10"
check_errs $? "Error creating Regression report"


##############################################################################
# $Log: ex_vmutil_reports_post_session.sh,v $
# Revision 1.4  2006/04/12 17:26:23  ddmello
# Removed the reports that used custom views, kept examples that will work for all installations
#
# Added a Regression report based on the new built-in reporting capability of vM 1.3
#
# Revision 1.3  2005/09/19 23:00:15  ddmello
# Modified to use the ex_vmutil_runs_summary.ecom for some additional runs reports that include CSV export for spreadsheets
#
# Some of the view names have changed
#
# Revision 1.2  2005/06/17 11:37:25  ddmello
# Tested with ZCPU Example
#
##############################################################################



