#! /bin/sh -f

##############################################################################
# $Id: ex_vmutil_reports_session.sh,v 1.5 Fri Apr 14 01:44:43 2006 adiel Exp $
#
# Purpose: Example shell script for creating session reports
# 
# Usage:   Call this script wen aggregating sessions
#
#          Ensure that you have set the following env-vars before 
#          launching your session:
#
#          EX_VMUTIL_VPLAN_FILE : package-relative or absolute path to 
#                                 verification plan file (.xml/.vplan)
#
#          BRUN_SESSION_DIR : report storage location
#	   EX_VMUTIL_VPLAN_FILE : vplan you want to use
#          EX_VMUTIL_VPLAN_PERSPECTIVE : vplans perspective to report on
#          EX_VMUTIL_FAILURE_VIEW: the runs analysis view to store
#          EX_VMUTIL_REGRESS_VIEW: regression report, session &vplan &runs view
#          LOAD_CODE: ecode for use with vM
#          
#          Reports will be created in the 'html_reports' sub-dir of the
#          session directory
#
#          Note from Adiel.
#          PLEASE PLEASE PLEASE....
#          PLEASE setup different views for 
#          EX_VMUTIL_VPLAN_PERSPECTIVE, EX_VMUTIL_FAILURE_VIEW and 
#          EX_VMUTIL_REGRESS_VIEW
#          
##############################################################################

# From : http://steve-parker.org/sh/exitcodes.shtml
check_errs()
{
  # Function. Parameter 1 is the return code
  # Para. 2 is text to display on failure.
  if [ "${1}" -ne "0" ]; then
    echo "ERROR # ${1} : ${2}"
    # as a bonus, make our script exit with the right error code.
    exit ${1}
  fi
}


# Since this script is called from the post-session hook, the 
# Reports can be placed in the session-dir under a new directory 'html_reports'
REPORTS_DIR=${BRUN_SESSION_DIR}/html_reports

###############



/bin/mkdir ${REPORTS_DIR}
check_errs $? "Error creating reports dir: $REPORTS_DIR"

# Runs reports

# Runs Report example
vmanager -batch -c "@$LOAD_CODE;setup;  @ex_vmutil/scripts/ex_vmutil_runs_summary \"${BRUN_SESSION_DIR}\" ${REPORTS_DIR} failure_report.html  ${EX_VMUTIL_FAILURE_VIEW} FALSE"
check_errs $? "Error creating ${EX_VMUTIL_FAILURE_VIEW} report"


# Session Coverage report
vmanager -batch -c "@$LOAD_CODE; setup;@ex_vmutil/scripts/ex_vmutil_cov_summary \"${BRUN_SESSION_DIR}\" ${REPORTS_DIR} coverage_report.html ${EX_VMUTIL_COV_VIEW} ${EX_VMUTIL_VPLAN_FILE} \"${EX_VMUTIL_VPLAN_PERSPECTIVE}\" VPLAN_REPORT FALSE FALSE 10 FALSE"
check_errs $? "Error creating vPlan report"

# Regression report
vmanager -batch -c "@$LOAD_CODE; setup;@ex_vmutil/scripts/ex_vmutil_reg_summary \"${BRUN_SESSION_DIR}\" ${REPORTS_DIR} regression_report.html Sessions ${EX_VMUTIL_VPLAN_FILE} \"${EX_VMUTIL_VPLAN_PERSPECTIVE}\" ${EX_VMUTIL_REGRESS_VIEW} Sessions FALSE 10"
check_errs $? "Error creating Regression report"


##############################################################################
# $Log: ex_vmutil_reports_session.sh,v $
# Revision 1.5 Fri Apr 14 01:44:43 2006 adiel 
# based on ex_vmutil_reports__post_session.sh made it more environment variable friendly so a single script can be called for lots of sessions and create 3 meaningfuyl reports, coverage, runs, regression.
# 
# Revision 1.4  2006/04/12 17:26:23  ddmello
# Removed the reports that used custom views, kept examples that will work for all installations
#
# Added a Regression report based on the new built-in reporting capability of vM 1.3
#
# Revision 1.3  2005/09/19 23:00:15  ddmello
# Modified to use the ex_vmutil_runs_summary.ecom for some additional runs reports that include CSV export for spreadsheets
#
# Some of the view names have changed
#
# Revision 1.2  2005/06/17 11:37:25  ddmello
# Tested with ZCPU Example
#
##############################################################################



