/*-----------------------------------------------------------------
File name     : shr_apb_reg_def_hookup.e
Title         : eRM package for the vr_ad_hookup protocol
Project       :
Developers    : Luud
Created       : Sun Oct 23 06:52:17 2005
Description   : 
Notes         : 
-------------------------------------------------------------------
Copyright 2005 (c) Luud Corp
-----------------------------------------------------------------*/
<'
package shr_apb;

//ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
//3. Instantiate the new register file under a unit in your environment.
//ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
  
extend shr_apb_env_u {
   reg_file : IP_XXXX vr_ad_reg_file;
};

//ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
//4. Instantiate an address map and a register sequence driver.
//ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
  
extend shr_apb_env_u {
   addr_map : vr_ad_map;
   rsd: vr_ad_sequence_driver is instance;
   keep rsd.addr_map == value(addr_map);
      keep rsd.default_bfm_sd == bus_bridge.
        as_a(ACTIVE BRIDGE shr_apb_agent_u).bridge_sequence_driver;
//   keep rsd.default_bfm_sd == masters[0].as_a(ACTIVE MASTER shr_apb_agent_u).driver;
};
  
//ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
//5. Allocate an address space for the register file by adding it to 
//  the address map at the desired offset.
//ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo

extend shr_apb_env_u {
   post_generate() is also {
      addr_map.add_with_offset(0,reg_file);
   };
};

//ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
//6. Implement the eVC BFM sequence driver`s vr_ad_execute_op() method,
//which takes the contents of the register operation and executes it.
//ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo

extend shr_apb_driver_u {
   vr_ad_execute_op(op_item : vr_ad_operation) : list of byte @clock is {
      if op_item is a REG vr_ad_operation (reg_op) {
         if op_item.direction == WRITE {
            sequence.write(op_item.address, reg_op.reg.read_reg_val());
         } else {
            result = pack(packing.low,sequence.read(op_item.address));
         };
      };
   };
};


//ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
// 7. Bind the eVC monitor to the address map for updating the register 
// model and collecting coverage.
//ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
extend shr_apb_bus_monitor_u {
   event reg_map_update;
   log_transfer() is {
      if cur_transfer.direction == WRITE {
         get_enclosing_unit(shr_apb_env_u).addr_map.update(
          cur_transfer.addr,pack(packing.low,cur_transfer.data),{});
      } else {
         compute get_enclosing_unit(shr_apb_env_u).addr_map.
             compare_and_update(cur_transfer.addr,
             pack(packing.low,cur_transfer.data));
      };
   };
}; // extend shr_apb_...

  
//ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
//You can now access the registers using the write_reg and read_reg macros.
//ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo

extend vr_ad_sequence_kind: [MY_SEQ];
extend MY_SEQ vr_ad_sequence {
   !tx_data : EX_REG_TX_DATA_0 vr_ad_reg;
   body() @driver.clock is only {
      write_reg tx_data;
   };
};

extend MAIN'kind shr_apb_sequence {   
    keep soft count == 0;
};

//oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
// This code will reset all the registers on post_generate()
//oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo

extend IP_XXXX vr_ad_reg_file {
    post_generate() is also {
       reset();
    }; // post_generate()...
}; //
  
'>

   
