~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
File name   : reg_file_access_seq.e

Title       : example of random access sequence

Created     : 2006

Description :  This example uses the sequence - ALL_REGS_IN_FILE.
               ALL_REGS_IN_FILE sequence lets you access an entire register-file.
               All the registers in the register file will be accessed in an ASCENDING,
               DESCENDING or RANDOM order.
               The parameters for the sequence are reg_file_kind, direction
               and order. You can also generate a register file outside the sequence
               and pass it to the reg_file field of the sequence.
              
              
Notes       :
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
Copyright 2006 (c) Cadence Design
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
<'
import vr_ad/examples/vr_ad_reg_sequence_lib;

extend MAIN vr_ad_sequence { 
   keep soft prevent_test_done == TRUE; 
}; 

extend vr_ad_sequence_kind: [ TEST_REGS ];
extend vr_ad_sequence {
   perform_reset() is {
   }; // perform_reset()...

}; // extend vr_ad_se...

extend TEST_REGS vr_ad_sequence {
   !rgf_seq      : ALL_REGS_IN_FILE vr_ad_sequence;
   !chk_access   : CHECK_REGS_ACCESS vr_ad_sequence;
   !chk_reset    : CHECK_RESET_VALUES vr_ad_sequence;
   
   body() @driver.clock is also {
      // Generate a register file with constraint on several registers inside
      var the_regs : IP_XXXX vr_ad_reg_file;
       
       // IP_XXXX register file will be generated randomly.
      do rgf_seq keeping {
         .reg_file_kind == IP_XXXX;
         .order == RANDOM;
         .direction == WRITE;
      }; 

      gen the_regs;

      // Write the register file in an ASCENDING order
      do rgf_seq keeping {
         .reg_file == the_regs;
         .order == ASCENDING;
         .direction == WRITE;
      };
            
      // Constrain the reg_file_kind to be IP_XXXX
      // Read the register file in a DESCENDING order
      do rgf_seq keeping {
         .reg_file_kind == IP_XXXX;
         .order == DESCENDING;
         .direction == READ;
      };

      // Write the register file in an ASCENDING order
      do rgf_seq keeping {
         .reg_file_kind == IP_XXXX;
         .order == DESCENDING;
         .direction == WRITE;
      };
            
      // Constrain the reg_file_kind to be IP_XXXX
      // Read the register file in a DESCENDING order
      do rgf_seq keeping {
         .reg_file_kind == IP_XXXX;
         .order == ASCENDING;
         .direction == READ;
      };
       
       // IP_XXXX register file will be generated randomly.
      do rgf_seq keeping {
         .reg_file_kind == IP_XXXX;
         .order == RANDOM;
         .direction == WRITE;
      }; 
             
      // Read the register file in a RANDOM order
      do rgf_seq keeping {
         .reg_file_kind == IP_XXXX;
         .order == RANDOM;
         .direction == READ;
      };

      // Constrain the reg_file_kind to be IP_XXXX
      // Read the register file in a DESCENDING order
      do rgf_seq keeping {
         .reg_file_kind == IP_XXXX;
         .order == DESCENDING;
         .direction == READ;
      };
       
      // Constrain the reg_file_kind to be IP_XXXX
      // Read the register file in a DESCENDING order
      do rgf_seq keeping {
         .reg_file_kind == IP_XXXX;
         .order == ASCENDING;
         .direction == READ;
      };
       
    
      // Check access to all registers
  //    do chk_access;
      
      perform_reset();
      // Check that all registers contain reset-values
      // ( Assumes that DUT was reset )
      do chk_reset;

            // Write the register file in an ASCENDING order
      do rgf_seq keeping {
         .reg_file_kind == IP_XXXX;
         .order == DESCENDING;
         .direction == WRITE;
      };
            
      // Constrain the reg_file_kind to be IP_XXXX
      // Read the register file in a DESCENDING order
      do rgf_seq keeping {
         .reg_file_kind == IP_XXXX;
         .order == ASCENDING;
         .direction == READ;
      };

   };
};

extend vr_ad_sequence_kind: [ WRITE_ONLY_REGS ];

extend WRITE_ONLY_REGS vr_ad_sequence {
   !rgf_seq      : ALL_REGS_IN_FILE vr_ad_sequence;
   !chk_access   : CHECK_REGS_ACCESS vr_ad_sequence;
   !chk_reset    : CHECK_RESET_VALUES vr_ad_sequence;
   
   body() @driver.clock is also {
      // Generate a register file with constraint on several registers inside
      var the_regs : IP_XXXX vr_ad_reg_file;
       
       // IP_XXXX register file will be generated randomly.
      do rgf_seq keeping {
         .reg_file_kind == IP_XXXX;
         .order == RANDOM;
         .direction == WRITE;
      }; 

      gen the_regs;

      // Write the register file in an ASCENDING order
      do rgf_seq keeping {
         .reg_file == the_regs;
         .order == ASCENDING;
         .direction == WRITE;
      };
            
      // Write the register file in an ASCENDING order
      do rgf_seq keeping {
         .reg_file_kind == IP_XXXX;
         .order == DESCENDING;
         .direction == WRITE;
      };
       
       // IP_XXXX register file will be generated randomly.
      do rgf_seq keeping {
         .reg_file_kind == IP_XXXX;
         .order == RANDOM;
         .direction == WRITE;
      }; 
                   
      perform_reset();
      // Check that all registers contain reset-values
      // ( Assumes that DUT was reset )
      do chk_reset;

            // Write the register file in an ASCENDING order
      do rgf_seq keeping {
         .reg_file_kind == IP_XXXX;
         .order == DESCENDING;
         .direction == WRITE;
      };

   };
};
'>