#! /bin/sh
#
#--------------------------------------------
# DUT compile
#--------------------------------------------

echo RUNNING SCRIPT $0 ...

#--------------------------------------------
# Verify we've got the env vars we need
#--------------------------------------------
for env_var in VMANAGER_HOME SPECMAN_HOME PACKAGE_PATH BRUN_SESSION_DIR BRUN_LOCAL_ECOM BRUN_RUN_MODE
do
    res=`set| grep "^$env_var="`
    if [ "$res" = "" ]
    then
	echo ERROR $0 exiting: $env_var not defined
	exit 1
    fi
done


#-------------------------------------------------
# Specifics of DVE files TB and DUT files
#-------------------------------------------------
my_dve_dut_files="${PACKAGE_PATH}/examples/tb_apb2.vhd"
my_dve_ve_files="${PACKAGE_PATH}/examples/shr_apb_config.e"


#-------------------------------------------------
# Commandline option to control model dumping
#-------------------------------------------------
BRUN_MODEL_DIR=${BRUN_MODEL_DIR:=.}
if [ "$1" = "-write_model" ]; then
   echo "Unicov write model:  ENABLED"
   echo BRUN_MODEL_DIR = "$BRUN_MODEL_DIR"
   if [ ! -d "$BRUN_MODEL_DIR" ]; then
      echo "Creating BRUN_MODEL_DIR since it doesn't exist"
      mkdir -p "$BRUN_MODEL_DIR"
   fi
   sn_unicov_options="config cover -write_model=ucm; config cover -database_format=ucd"
   ius_unicov_options=""
else
   echo "Unicov write model:  DISABLED"
   sn_unicov_options="config cover -database_format=ucd"
   ius_unicov_options="-covnomodeldump"
fi

if [ "$1" = "-igen" ]; then
   sn_igen_setup="config gen -default_generator=IntelliGen"
   else
   sn_igen_setup=""
fi

if [ "$2" = "-igen" ]; then
   sn_igen_setup="config gen -default_generator=IntelliGen"
   else
   sn_igen_setup=""
fi

#-------------------------------------------------
# Verify sim build directory available
#-------------------------------------------------
snapshot_path=${BRUN_SESSION_DIR}/session_builds/`${VMANAGER_HOME}/bin/vm_arch.sh`
if [ ! -d ${snapshot_path} ]; then
    mkdir -p ${snapshot_path}
fi

if [ ! -d ${snapshot_path} ]; then
    echo ERROR $0 exiting: cannot locate or create snapshot build directory $snapshot_path
    exit 1;
fi


#-------------------------------------------------
# build and run dve 
#-------------------------------------------------

#ius_cov="-covdut xor_dut -covdut cdv_xor_if -coverage b:e:u"


# Move Specman-pre_commands for use by irun -snprerun option
SPECMAN_PRE_COMMANDS="$sn_unicov_options; $SPECMAN_PRE_COMMANDS; @$BRUN_LOCAL_ECOM; "
echo $SPECMAN_PRE_COMMANDS > ./sn_pre_run.ecom
SPECMAN_PRE_COMMANDS=""; export SPECMAN_PRE_COMMANDS;


# irun run command tcl file
echo "run" > ./irun.tcl


###################################################
# Build snapshot.
# Put lock around the process to prevent collisions
# with parallel running.
###################################################
echo "Build snapshot"
echo `pwd`
vm_simple_lock_and_count.pl 1 $snapshot_path/.lock_details "Building snapshot" "
irun \
  -c -nclibdirpath ${snapshot_path} \
  $my_dve_dut_files $my_dve_ve_files \
  -top WORKLIB.TOP \
  -snset \"$sn_igen_setup\"
"
#   $ius_cov \ removed

###################################################
# Run using snapshot built above
###################################################
irun_run="irun -R -nclibdirpath ${snapshot_path} -snset \"$sn_igen_setup\" -snprerun @./sn_pre_run.ecom $ius_unicov_options +nowarnENUMERR"


# Determine run_mode
if [ -n $BRUN_RUN_MODE ]; then
   case `echo $BRUN_RUN_MODE` in
      interactive)
         cmd="$irun_run +gui -input ${PACKAGE_PATH}/scripts/irun_debug.tcl"
         ;;
      interactive_debug)
         cmd="$irun_run +gui -input ${PACKAGE_PATH}/scripts/irun_debug.tcl"
         ;;
      batch_debug)
         cmd="$irun_run -input -input ${PACKAGE_PATH}/scripts/irun_debug.tcl ${PACKAGE_PATH}/scripts/irun_batch.tcl"
         ;;
      *) # run batch
         cmd="$irun_run -input ${PACKAGE_PATH}/scripts/irun_batch.tcl"
         ;;
   esac
fi


# Exectute the commandline
echo "Compiling and Running DVE"
echo Executing: $cmd
eval ${cmd}


#--------------------------------------------
#------ Done !
#--------------------------------------------
echo FINISHED $0: exiting normally
# exit 0

